@@ -15,6 +15,7 @@
 
 import os
 import json
+import time
 import hashlib
 import sqlite3
 
@@ -56,7 +57,7 @@ def setup( ) :
     init_schema( )
 
     if( os.path.isfile( db_filepath ) ) :
-        sys_update("rev",rev)
+        sys_update( "rev" , rev )
         #s_log.write("REV setup " + str( rev ) )
         return( True )
 
@@ -203,7 +204,7 @@ def init_schema( ) :
 
     sql_execute( "CREATE TABLE sys ( sn text UNIQUE , sv text )" )
     sql_execute( "CREATE INDEX index_sys ON sys ( sn )" )
-    
+
     sys_create( "ver" , 1 )
     sys_create( "serial" , "ODS042e1919c5bd8f41cd8e1a2b8e455dd8f6fb00df0c3916d1137047a7aafc4c42" )
     sys_create( "rev" , 1 )
@@ -417,7 +418,7 @@ def meta_readall( ) :
     rows = table_readall( "meta" )
     return( rows )
 
-def meta_update( mn,mv_in ) :
+def meta_update( mn , mv_in ) :
     mv = s_util.json_encode( mv_in )
     sql = "UPDATE meta SET mv=? where mn=?"
     data = ( mv , mn )
@@ -433,6 +434,42 @@ def meta_deleteall( ) :
     table_truncate( "meta" )
 
 
+def meta_checkupdefault( ) :
+    mn = "_default_5800b137d"
+    t = meta_read( mn )
+    if not t :
+        meta_setdefault( )
+
+
+def meta_createorupdate( mn , mv ) :
+    t = meta_read( mn )
+    if t :
+        meta_update( mn , mv )
+    else :
+        meta_create( mn , mv )
+
+
+
+def meta_setdefault( mv_in = False ) :
+    # _default_5800b137d
+
+    d = { "_time" : time.time( ) }
+
+    if mv_in :
+        d.update( mv_in )
+
+    mn = "_default_5800b137d"
+    meta_createorupdate( mn , d )
+    return( True )
+
+def meta_getdefault( ) :
+    # _default_5800b137d
+    mn = "_default_5800b137d"
+    mv = meta_read( mn )
+    return( mv )
+
+
+
 ####################################################################
 
 def args_create( av ) :
