@@ -124,6 +124,10 @@ def check_connectivity( ) :
 
 def job_request( ) :
 
+    if( not s_util.ready( ) ) :
+        s_log.write( "NOT READY" )
+        return( False )
+
     db_filecontents = s_db.file_contents( )
 
     payload = gzip.compress( db_filecontents  )
@@ -182,10 +186,11 @@ def job_responsewait( jid , timeout = 60 ) :
         if( jr == False ) : return( False )
         if( jr == True ) : return( True )
         if( time.time( ) - time_start ) > timeout : return( None )
+        time.sleep( 0.1 )
 
 def job_response( jid ) :
 
-    s_db.setup( )
+    #s_db.setup( )
 
     #time.sleep(1)
 
@@ -244,8 +249,18 @@ def job_response( jid ) :
     return( True )
 
 
+# FIXME TODO feel it could be improved
+job_id = False
 def job_get( ) :
 
+    global job_id
+
+    job_id = False
+
+    if( not s_util.ready( ) ) :
+        s_log.write( "NOT READY" )
+        return( False )
+
     mw = mw_get( )
     if( not mw ) : return( False )
 
@@ -275,7 +290,7 @@ def job_get( ) :
     #s_log.write( str(res.headers ) )
 
     if( not "X-Omni-Jid" in res.headers ) :
-        s_log.write( "Not found X-Omni-Jid" )
+        #s_log.write( "Not found X-Omni-Jid" )
         return( None )
 
     payload = gzip.decompress( res.content )
@@ -291,13 +306,19 @@ def job_get( ) :
         context_json = s_util.base64_decode( res.headers[ "X-Omni-Context" ] )
         #s_db.meta_create( "_server_getjob_context_json" , context_json ) 
 
-    if( "X-Omni-Jid" in res.headers ) :
-        s_db.meta_create( "_jid" , res.headers[ "X-Omni-Jid" ] ) 
-        s_log.write( "job_get [" + res.headers[ "X-Omni-Jid" ] + "]" )
+    #if( "X-Omni-Jid" in res.headers ) :
+    job_id=res.headers[ "X-Omni-Jid" ]
+    s_db.meta_create( "_jid" , job_id ) 
+    s_log.write( "job_get [" + job_id + "]" )
 
     return( True )
 
-def job_set( jid ) :
+def job_set( jid = False ) :
+
+    if not jid :
+        jid = job_id
+
+    s_db.meta_checkupdefault( )
 
     s_db.sys_rev_inc( )
 
