@@ -29,16 +29,10 @@ s_db.setup( )
 #####################################################################
 
 def ready( ) :
-    if( not s_config.config_ready_get( ) ) :
-        return( False )
-
-    if( not s_net.check_connectivity( ) ) :
-        return( False )
-
-    return( True )
+    return( s_util.ready( ) )
 
 def prexit( msg ) :
-    s_util.printexit( "FALSE tables" )
+    s_util.printexit( msg )
 
 def defout( ) :
     return( s_db.files_get_defaultdata( ) )
@@ -46,6 +40,9 @@ def defout( ) :
 def uptime( ) :
     return( s_util.uptime( ) )
 
+def heartbeat( t = 60 ) :
+    return( s_util.heartbeat( t ) )
+
 #####################################################################
 
 # DATA
@@ -70,10 +67,10 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
-    f = s_db.meta_create( "_" , meta_inputs ) 
+    f = s_db.meta_setdefault( meta_inputs ) 
 
     if( not f ) :
-        s_log.write( "false meta_add " + k )
+        s_log.write( "false meta_add " )
         return( False )
 
     #####################################################################
@@ -88,8 +85,12 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
+    t1=uptime()
+
     jr = s_net.job_responsewait( jid , wait_timeout )
 
+    s_log.write(uptime()-t1)
+
     if( jr == False ) :
         s_log.write( "false job_wait" )
         return( False )
@@ -103,9 +104,9 @@ def express( meta_inputs = { } , wait_timeout = 60 ) :
     #s_log.write(s_util.uptime())
 
     if( s_db.stdio_has_stderr( ) ) :
-        s_log.write( s_db.stdio_get_stderr( ) )
+        s_log.write( "ERROR stdio_has_stderr " + s_db.stdio_get_stderr( ) )
         return( None )
 
     #####################################################################
 
-    return( s_db.meta_read( "_" ) )
+    return( s_db.meta_getdefault( ) )
